@@ -121,6 +121,18 @@ int print_which_recs = 0;	/* If 0, only print the usual.  If 1,
 int print_addresses = 0;	/* should we print the ut_addr field? */
 #endif
 
+/* Some systems (like Linux with the newer glibc) have very long field
+   lengths for usernames, ttys, and hostnames.  While it's useful to
+   print out the entire values from time to time, the casual browser
+   doesn't care (and it screws up the 80-column formatting).  Keep
+   track of desired field widths with these variables. */
+
+#define my_min(x,y) ((x) < (y) ? (x) : (y))
+int print_name_len = my_min (NAME_LEN, 8);
+int print_tty_len = my_min (TTY_LEN, 12);
+int print_host_len = my_min (HOST_LEN, 16);
+#undef my_min
+
 
 /* A table of names/ttys that the user wants to know about.  */
 
@@ -225,6 +237,7 @@ main (int argc, char *argv[])
 #endif
 	{ "tw-suspicious", required_argument, NULL, 14 },
 	{ "print-seconds", no_argument, NULL, 15 },
+	{ "wide", no_argument, NULL, 16 },
 	{ 0, 0, 0, 0 }
       };
 
@@ -239,7 +252,7 @@ main (int argc, char *argv[])
 #ifdef HAVE_UT_TYPE
 		              "x"
 #endif
-		               "yV",
+		               "wyV",
 		       long_options, &option_index);
       
       if (c == EOF)
@@ -312,6 +325,14 @@ main (int argc, char *argv[])
 	case 15:
 	  print_seconds = 1;
 	  break;
+	case 'w':
+	case 16:
+	  /* Print the entire field widths, rather than our
+             conservative, 80-column defaults */
+	  print_name_len = NAME_LEN;
+	  print_tty_len = TTY_LEN;
+	  print_host_len = HOST_LEN;
+	  break;
 	case 'h':
 	case 7:
 	  /* This should fall through to default! */
@@ -640,8 +661,8 @@ print_record (struct utmp *login, time_t logout_time,
   /* Print the name and tty. */
 
   printf ("%-*.*s %-*.*s ",
-	  NAME_LEN, NAME_LEN, print_name,
-	  TTY_LEN, TTY_LEN, sanitized_tty);
+	  print_name_len, print_name_len, print_name,
+	  print_tty_len, print_tty_len, sanitized_tty);
 
 
 #ifdef HAVE_UT_ADDR
@@ -659,7 +680,7 @@ print_record (struct utmp *login, time_t logout_time,
          beyond 80 characters in width. */
   if (!print_addresses)
 #endif
-    printf ("%-*.*s ", HOST_LEN, HOST_LEN, login->ut_host);
+    printf ("%-*.*s ", print_host_len, print_host_len, login->ut_host);
 #endif
 
   display_date (login->ut_time);
