@@ -21,6 +21,11 @@ MA 02139, USA.  */
 
 #include "config.h"
 #include <stdio.h>
+
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+
 #include <ctype.h>
 
 #ifdef HAVE_STRING_H
@@ -60,6 +65,7 @@ int debugging_enabled = 0;	/* Nonzero means print internal
 int strict_match_flag = 0;	/* Nonzero if each record has to match
 				   all items on the command line */
 int print_controls = 0;		/* don't print control characters */
+int ahz = AHZ;			/* for viewing logs from another system */
 
 char *program_name;		/* name of the program, for usage & errs */
 
@@ -112,6 +118,7 @@ main (int argc, char *argv[])
 	{ "user", required_argument, NULL, 7 },
 	{ "tty", required_argument, NULL, 8 },
 	{ "command", required_argument, NULL, 9 },
+	{ "ahz", required_argument, NULL, 10 },
 	{ 0, 0, 0, 0 }
       };
       
@@ -157,6 +164,16 @@ main (int argc, char *argv[])
 	    command_list = hashtab_init (0);
 	  hashtab_create (command_list, optarg, 0);
 	  break;
+	case 10:
+	  ahz = atoi (optarg);
+
+	  if (ahz < 1)
+	    {
+	      printf ("%s: AHZ must be one or greater\n", program_name);
+	      exit (1);
+	    }
+
+	  break;
 	case 'h':
 	case 3:
 	  /* This should fall through to default! */
@@ -182,6 +199,24 @@ main (int argc, char *argv[])
 	hashtab_create (all_list, argv[optind++], 0);
     }
   
+  /* If the "strict-match" flag was selected, make sure the user
+     hasn't specified multiple usernames, ttys, or command names. */
+
+  if (strict_match_flag)
+    {
+      if ((tty_list && (tty_list->items_hashed > 1))
+	  || (user_list && (user_list->items_hashed > 1))
+	  || (command_list && (command_list->items_hashed > 1)))
+	{
+	  printf ("%s: ERROR: when using the `--strict-match' flag,\n"
+		  "   it is nonsensical to specify more than one item\n"
+		  "   to match in a single category (using the `--tty',\n"
+		  "   `--user', or `--command' flags).\n",
+		  program_name);
+	  exit (1);
+	}
+    }
+
   if (debugging_enabled)
     {
       if (all_list)
@@ -316,7 +351,7 @@ parse_entries (void)
 	  
 	  printf (" %-8.8s %-8.8s %6.2f secs %-16.16s\n",
 		  this_uid, this_dev,
-		  ((ut + st) / (double) AHZ),
+		  ((ut + st) / (double) ahz),
 		  ctime (&rec->ac_btime));
 	}
     }
@@ -339,13 +374,45 @@ desired_entry (char *uid, char *dev, char *comm)
 
   if (strict_match_flag)
     {
-      /* All categories must have one match. */
+      /* We must match each element in all_list to the current record.
+	 This makes the intuitive usage
 
-      if (all_list
-	  && hashtab_find (all_list, uid, 0) == NULL
-	  && hashtab_find (all_list, dev, 0) == NULL
-	  && hashtab_find (all_list, comm, COMM_LEN) == NULL)
-	return 0;
+	   lastcomm --strict-match noel cat ttyp2
+
+	 work correctly. */
+
+      if (all_list)
+	{
+	  struct hashtab_order ho;
+	  struct hashtab_elem *he;
+	  
+	  for (he = hashtab_first (all_list, &ho);
+	       he != NULL;
+	       he = hashtab_next (&ho))
+	    {
+	      /* While both the uid and dev will be null-terminated,
+		 comm may not be (especially if it contains COMM_LEN
+		 characters).  We therefore need to figure out the
+		 length of comm (which is a maxiumum of COMM_LEN) and
+		 use strncmp below instead of strcmp. */
+
+	      int commlen = strlen (comm);
+	      if (commlen > COMM_LEN)
+		commlen = COMM_LEN;
+
+	      /* We must match at least one of these items. */
+
+	      if (strcmp (he->key, uid)
+		  || strcmp (he->key, dev)
+		  || strncmp (he->key, comm, commlen))
+		return 0;
+	    }
+	}
+
+      /* Now handle matches for individual categories (with `--tty' &
+	 c.).  Since we've guaranteed above that each of the following
+	 lists will only contain a single item, we can use
+	 hashtab_find to see if that item matches the given string. */
       
       if (tty_list && hashtab_find (tty_list, dev, 0) == NULL)
 	return 0;
