@@ -8,7 +8,7 @@
 
 /* This looks strange, but it's real ANSI C. */
 
-static struct acct pacct_rd_never_used;
+extern struct acct pacct_rd_never_used;
 
 #define COMM_LEN ((int) sizeof (pacct_rd_never_used.ac_comm))
 
