@@ -171,6 +171,7 @@ int dont_read_summary_files = 0;
 int print_users = 0;
 int percentages = 0;		/* include percentages in printout */
 int user_summary_flag = 0;	/* are we printing a user summary? */
+int ahz = AHZ;			/* for viewing logs from another system */
 
 
 #if defined(HAVE_ACUTIME) && defined(HAVE_ACSTIME)
@@ -340,6 +341,7 @@ main (int argc, char *argv[])
 #ifdef HAVE_ACETIME
 	{ "sort-real-time", no_argument, NULL, 26 },
 #endif
+	{ "ahz", required_argument, NULL, 27 },
 	{ 0, 0, 0, 0 }
       };
       
@@ -502,6 +504,16 @@ main (int argc, char *argv[])
 	  sort_type = sort_real_time;
 	  break;
 #endif
+	case 27:
+	  ahz = atoi (optarg);
+
+	  if (ahz < 1)
+	    {
+	      printf ("%s: AHZ must be one or greater\n", program_name);
+	      exit (1);
+	    }
+
+	  break;
 	case 'h':
 	case 3:
 	  /* This should fall through to default! */
@@ -551,7 +563,7 @@ main (int argc, char *argv[])
 
   if (debugging_enabled)
     {
-      fprintf (stddebug, "AHZ -> %d\n", AHZ);
+      fprintf (stddebug, "AHZ -> %d\n", ahz);
       fprintf (stddebug, "getpagesize() -> %d\n", getpagesize ());
       fprintf (stddebug, "system_page_size == %.2f\n", system_page_size);
     }
@@ -1103,33 +1115,36 @@ acct entries\n\
     {
 #ifdef HAVE_ACUTIME
 # ifdef ACUTIME_COMPT
-      double ut = comp_t_2_double (rec->ac_utime) / (double) AHZ;
+      double ut = comp_t_2_double (rec->ac_utime) / (double) ahz;
 # else
-      double ut = (double) rec->ac_utime / (double) AHZ;
+      double ut = (double) rec->ac_utime / (double) ahz;
 # endif
 #endif
 
 #ifdef HAVE_ACSTIME
 # ifdef ACSTIME_COMPT
-      double st = comp_t_2_double (rec->ac_stime) / (double) AHZ;
+      double st = comp_t_2_double (rec->ac_stime) / (double) ahz;
 # else
-      double st = (double) rec->ac_stime / (double) AHZ;
+      double st = (double) rec->ac_stime / (double) ahz;
 # endif
 #endif
 
 #ifdef HAVE_ACETIME
 # ifdef ACETIME_COMPT
-      double et = comp_t_2_double (rec->ac_etime) / (double) AHZ;
+      double et = comp_t_2_double (rec->ac_etime);
 # else
-      double et = (double) rec->ac_etime / (double) AHZ;
+      double et = (double) rec->ac_etime;
+# endif
+# ifdef ACETIME_AHZ
+      et /= (double) ahz;
 # endif
 #endif
 
 #ifdef HAVE_ACIO
 # ifdef ACIO_COMPT
-      double di = comp_t_2_double (rec->ac_io) / (double) AHZ;
+      double di = comp_t_2_double (rec->ac_io) / (double) ahz;
 # else
-      double di = (double) rec->ac_io / (double) AHZ;
+      double di = (double) rec->ac_io / (double) ahz;
 # endif
 #endif
 
@@ -1431,7 +1446,7 @@ print_user_list (void)
   num_users++;			/* one for the summary entry */
 
   entry_array = (struct hashtab_elem **)
-    xmalloc (sizeof (struct hashtab_elem *) * (num_users + 1));
+    xmalloc (sizeof (struct hashtab_elem *) * num_users);
 
   which = 0;
   entry_array[which++] = &user_totals;
